@@ -1,6 +1,6 @@
 /*******************************************************************************
     PRODIGAL (PROkaryotic DynamIc Programming Genefinding ALgorithm)
-    Copyright (C) 2007-2014 University of Tennessee / UT-Battelle
+    Copyright (C) 2007-2015 University of Tennessee / UT-Battelle
 
     Code Author:  Doug Hyatt
 
@@ -26,8 +26,8 @@
 #include "dprog.h"
 #include "gene.h"
 
-#define VERSION "2.6.1"
-#define DATE "July, 2013"
+#define VERSION "2.6.2"
+#define DATE "February, 2015"
 
 #define MIN_SINGLE_GENOME 20000
 #define IDEAL_SINGLE_GENOME 100000
@@ -154,7 +154,7 @@ int main(int argc, char *argv[]) {
     }
     else if(strcmp(argv[i], "-g") == 0 || strcmp(argv[i], "-G") == 0) {
       tinf.trans_table = atoi(argv[i+1]);
-      if(tinf.trans_table < 1 || tinf.trans_table > 23 || tinf.trans_table == 7
+      if(tinf.trans_table < 1 || tinf.trans_table > 25 || tinf.trans_table == 7
          || tinf.trans_table == 8 || (tinf.trans_table >= 17 && tinf.trans_table
          <= 20))
         usage("Invalid translation table specified.");
@@ -657,14 +657,12 @@ void help() {
   fprintf(stderr, "         -g:  Specify a translation table to use (default");
   fprintf(stderr, " 11).\n");
   fprintf(stderr, "         -h:  Print help menu and exit.\n");
-  fprintf(stderr, "         -i:  Specify input file (default reads from ");
-  fprintf(stderr, "stdin).\n");
-  fprintf(stderr, "         -m:  Treat runs of n's as masked sequence and do");
-  fprintf(stderr, " not build genes across \n");
-  fprintf(stderr, "              them.\n");
-  fprintf(stderr, "         -n:  Bypass the Shine-Dalgarno trainer and force");
-  fprintf(stderr, " the program to scan\n");
-  fprintf(stderr, "              for motifs.\n");
+  fprintf(stderr, "         -i:  Specify FASTA/Genbank input file (default ");
+  fprintf(stderr, "reads from stdin).\n");
+  fprintf(stderr, "         -m:  Treat runs of N as masked sequence; don't");
+  fprintf(stderr, " build genes across them.\n");
+  fprintf(stderr, "         -n:  Bypass Shine-Dalgarno trainer and force");
+  fprintf(stderr, " a full motif scan.\n");
   fprintf(stderr, "         -o:  Specify output file (default writes to ");
   fprintf(stderr, "stdout).\n");
   fprintf(stderr, "         -p:  Select procedure (single or meta).  Default");
