@@ -1,6 +1,6 @@
 /*******************************************************************************
     PRODIGAL (PROkaryotic DynamIc Programming Genefinding ALgorithm)
-    Copyright (C) 2007-2014 University of Tennessee / UT-Battelle
+    Copyright (C) 2007-2015 University of Tennessee / UT-Battelle
 
     Code Author:  Doug Hyatt
 
@@ -58,7 +58,7 @@ int read_seq_training(FILE *fp, unsigned char *seq, unsigned char *useq,
     else if(hdr == 1 && (line[0] == '/' && line[1] == '/')) hdr = 0;
     else if(hdr == 1) {
       if(strstr(line, "Expand") != NULL && strstr(line, "gap") != NULL) {
-        sscanf(strstr(line, "gap")+4, "%d", &gapsize); 
+        sscanf(strstr(line, "gap")+4, "%u", &gapsize); 
         if(gapsize < 1 || gapsize > MAX_LINE) {
           fprintf(stderr, "Error: gap size in gbk file can't exceed line");
           fprintf(stderr, " size.\n");
@@ -169,7 +169,7 @@ int next_seq_multi(FILE *fp, unsigned char *seq, unsigned char *useq,
     }
     else if(reading_seq == 1) {
       if(strstr(line, "Expand") != NULL && strstr(line, "gap") != NULL) {
-        sscanf(strstr(line, "gap")+4, "%d", &gapsize); 
+        sscanf(strstr(line, "gap")+4, "%u", &gapsize); 
         if(gapsize < 1 || gapsize > MAX_LINE) {
           fprintf(stderr, "Error: gap size in gbk file can't exceed line");
           fprintf(stderr, " size.\n");
@@ -299,7 +299,7 @@ int is_stop(unsigned char *seq, int n, struct _training *tinf) {
     if((tinf->trans_table >= 2 && tinf->trans_table <= 5) ||
        tinf->trans_table == 9 || tinf->trans_table == 10 ||
        tinf->trans_table == 13 || tinf->trans_table == 14 ||
-       tinf->trans_table == 21) return 0;
+       tinf->trans_table == 21 || tinf->trans_table == 25) return 0;
     return 1;
   }
 
@@ -346,7 +346,7 @@ int is_start(unsigned char *seq, int n, struct _training *tinf) {
   /* TTG */
   if(is_t(seq, n) == 1 && is_t(seq, n+1) == 1 && is_g(seq, n+2) == 1) {
     if(tinf->trans_table < 4 || tinf->trans_table == 9 ||
-       tinf->trans_table >= 21) return 0;
+       (tinf->trans_table >= 21 && tinf->trans_table < 25)) return 0;
     return 1;
   }
 
@@ -414,8 +414,10 @@ char amino(unsigned char *seq, int n, struct _training *tinf, int is_init) {
     return 'C';
   if(is_t(seq, n) == 1 && is_g(seq, n+1) == 1 && is_c(seq, n+2) == 1)
     return 'C';
-  if(is_t(seq, n) == 1 && is_g(seq, n+1) == 1 && is_a(seq, n+2) == 1)
-    return 'W';
+  if(is_t(seq, n) == 1 && is_g(seq, n+1) == 1 && is_a(seq, n+2) == 1) {
+    if(tinf->trans_table == 25) return 'G';
+    else return 'W';
+  }
   if(is_t(seq, n) == 1 && is_g(seq, n+1) == 1 && is_g(seq, n+2) == 1)
     return 'W';
   if(is_c(seq, n) == 1 && is_t(seq, n+1) == 1 && is_t(seq, n+2) == 1) {
